from sys import version_info as py_ver

if py_ver[0] == 3 and py_ver[1] >= 8:

	from importlib.metadata import PackageNotFoundError
	from importlib.metadata import version as pkg_version


	def check_version(package: str):
		try:
			return pkg_version(package)
		except PackageNotFoundError:
			return False

else:
	import pkg_resources as pkg
	def check_version(package: str):
		try:
			return pkg.get_distribution(package).version
		except :
			return False



import sys
import argparse
from pip_search.pip_search import search


def main():
    ap = argparse.ArgumentParser()
    ap.add_argument('query', nargs='+', type=str,
                    help='terms to search pypi.org package repository')
    args = ap.parse_args()
    search(query=' '.join(args.query))


if __name__ == '__main__':
    sys.exit(main())



import pathlib
from setuptools import setup, find_packages

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setup(
    name="pip_search",
    version="0.0.9",
    author="Victor Garric",
    author_email="victor.garric@gmail.com",
    url='https://github.com/victorgarric/pip_search',
    description="A package to search like pip used to via PyPi",
    long_description=README,
    long_description_content_type='text/markdown',
    packages=find_packages(exclude=("tests",)),
    install_requires=['bs4', 'requests', 'rich'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.',
    entry_points={
        "console_scripts": [
            "pip_search=pip_search.__main__:main",
        ],
    },
)



from rich.console import Console
from rich.table import Table
from bs4 import BeautifulSoup
from urllib.parse import urljoin
from .utils import check_version
import requests
import re


def search(query: str):
    api_url = "https://pypi.org/search/"
    snippets = []
    s = requests.Session()
    for page in range(1, 3):
        params = {"q": query, "page": page}
        r = s.get(api_url, params=params)
        soup = BeautifulSoup(r.text, "html.parser")
        snippets += soup.select('a[class*="snippet"]')
        if not hasattr(s, "start_url"):
            s.start_url = r.url.rsplit("&page", maxsplit=1).pop(0)

    table = Table(
        title=(
            f"[not italic]:snake:[/] [bold][magenta]{s.start_url} "
            "[not italic]:snake:[/]"
        )
    )
    table.add_column("Package", style="cyan", no_wrap=True)
    table.add_column("Version", style="bold yellow")
    table.add_column("Released", style="bold green")
    table.add_column("Description", style="bold blue")
    for snippet in snippets:
        link = urljoin(api_url, snippet.get("href"))
        package = re.sub(
            r"\s+", " ", snippet.select_one('span[class*="name"]').text.strip()
        )
        version = re.sub(
            r"\s+",
            " ",
            snippet.select_one('span[class*="version"]').text.strip(),
        )
        checked_version = check_version(package)
        if checked_version == version:
            version = f"[bold cyan]{version} ==[/]"
        elif checked_version is not False:
            version = f"{version} > [bold purple]{checked_version}[/]"
        released = re.sub(
            r"\s+",
            " ",
            snippet.select_one('span[class*="released"]').text.strip(),
        )
        description = re.sub(
            r"\s+",
            " ",
            snippet.select_one('p[class*="description"]').text.strip(),
        )
        emoji = ":open_file_folder:"
        table.add_row(
            f"[link={link}]{emoji}[/link] {package}",
            version,
            released,
            description,
        )

    console = Console()
    console.print(table)
    return
